@@ -15,7 +15,7 @@ HEADER_ATTRS = OrderedDict([
     ('packet_len', ('i', 0)),
     ('cmd', ('i', 0)),
     ('ret', ('i', 0)),
-    ('sn', ('i', 0)),
+    ('sn', ('q', 0)),
 ])
 
 
